︠0fedd3a0-bb90-4422-9046-c8727de64b65i︠
%md
 * This is a tutorial for how to compute braid variety quivers.
 * To run the code, download it [here](https://www.math.ucla.edu/~galashin/DoubleBraidCluster/DoubleBraidCluster.zip), and unpack it into a [CoCalc](https://cocalc.com/) project.
 * See \[GLSBS22\]=[arXiv:2210.04778](http://arxiv.org/abs/2210.04778) and
 [GLSB23]=[arXiv:2301.07268](http://arxiv.org/abs/2301.07268).
 * Code by [Pavel Galashin](https://www.math.ucla.edu/~galashin/index.html), posted 01/16/23.
︡82b9f035-7907-41c3-a638-c5a36b6c7b18︡{"done":true,"md":" * This is a tutorial for how to compute braid variety quivers.\n * To run the code, download it [here](https://www.math.ucla.edu/~galashin/DoubleBraidCluster/DoubleBraidCluster.zip), and unpack it into a [CoCalc](https://cocalc.com/) project.\n * See \\[GLSBS22\\]=[arXiv:2210.04778](http://arxiv.org/abs/2210.04778) and\n [GLSB23]=[arXiv:2301.07268](http://arxiv.org/abs/2301.07268).\n * Code by [Pavel Galashin](https://www.math.ucla.edu/~galashin/index.html), posted 01/16/23."}
︠4791a0b5-fd5c-4ccf-83b7-424446f7bb7ds︠
#press shift+enter to load the files
load("DoubleBraidClusterA.py","DoubleBraidClusterGen.py")
︡99a8a981-0c44-4f01-8e44-e207f6675df6︡{"done":true}
︠fd32b661-2489-4f1d-9d4f-314e50c43eabi︠
%md
 * ``DoubleBraidClusterA`` computes type A quivers as in \[GLSBS22\]
 * ``DoubleBraidClusterGen`` computes quivers of arbitrary type as in \[GLSB23\].
 * In type A, you have to specify two parameters, ``wred`` and ``ured``.
 	* ``wred`` is an arbitrary word with positive and negative letters.
 	* ``ured`` is a reduced word on positive letters, that is less than or equal to the Demazure product of ``wred``.
 * The output will be a pdf file in the ``tex/`` directory. The output links are clickable.
︡fb852005-6501-4d56-a5bb-a982aaeb3140︡{"done":true,"md":" * ``DoubleBraidClusterA`` computes type A quivers as in \\[GLSBS22\\]\n * ``DoubleBraidClusterGen`` computes quivers of arbitrary type as in \\[GLSB23\\].\n * In type A, you have to specify two parameters, ``wred`` and ``ured``.\n \t* ``wred`` is an arbitrary word with positive and negative letters.\n \t* ``ured`` is a reduced word on positive letters, that is less than or equal to the Demazure product of ``wred``.\n * The output will be a pdf file in the ``tex/`` directory. The output links are clickable."}
︠50455160-6654-453a-bf30-743387acdb96s︠
DoubleBraidClusterA.print_single(wred=[2,1,-2,2,-2,-1,2,2],ured=[2,1],file_name="simple_test")
︡07cddf0a-a974-4e41-83d8-42b673042ade︡{"html":"OK! <a href='tex/simple_test.pdf'>simple_test.pdf</a>"}︡{"done":true}
︠a4eb26b2-39cb-45e8-a915-5ab9967cf4f8i︠
%md
By default, it will output a wiring diagram, followed by the monotone curves which are sections of the corresponding 3D disks; see Section 3 of \[GLSBS22\]. Some details:

* The picture is drawn as a double wiring diagram, with red and blue crossings corresponding to the positive and negative indices in ``wred``.
* The quiver vertices are drawn on the solid crossings.
* The frozen/mutable vertices are grey/green. The arrows between mutable vertices are thick. Each arrow has 3 arrowheads.
* The red/blue labels in the wiring diagram indicate how red/blue grid minors factor into cluster variables

Here's a screenshot from ``simple_test.pdf``:

<img src="https://www.math.ucla.edu/~galashin/DoubleBraidCluster/simple_test_screenshot.png">
<!-- <img src="screenshots/simple_test.png"> -->

You can specify what to print using the various options. For instance, let's omit the curves (``print_curves=False``), and instead print the $X_c,Y_c,Z_c$ matrices (``print_matrices=True``). We set ``use_a1_paper=True`` so that the matrices would fit on the page. We also print grid minors $\Delta_{c,k}$ (``print_red/blue_minors=True``) instead of their factorizations into cluster variables (``print_red/blue_factorizations=False``). To see the full list of options, type ``DoubleBraidClusterA.print_and_compile?``
︡220dea4d-0f08-4ca0-8109-195f1008e248︡{"done":true,"md":"By default, it will output a wiring diagram, followed by the monotone curves which are sections of the corresponding 3D disks; see Section 3 of \\[GLSBS22\\]. Some details:\n\n* The picture is drawn as a double wiring diagram, with red and blue crossings corresponding to the positive and negative indices in ``wred``.\n* The quiver vertices are drawn on the solid crossings.\n* The frozen/mutable vertices are grey/green. The arrows between mutable vertices are thick. Each arrow has 3 arrowheads.\n* The red/blue labels in the wiring diagram indicate how red/blue grid minors factor into cluster variables\n\nHere's a screenshot from ``simple_test.pdf``:\n\n<img src=\"https://www.math.ucla.edu/~galashin/DoubleBraidCluster/simple_test_screenshot.png\">\n<!-- <img src=\"screenshots/simple_test.png\"> -->\n\nYou can specify what to print using the various options. For instance, let's omit the curves (``print_curves=False``), and instead print the $X_c,Y_c,Z_c$ matrices (``print_matrices=True``). We set ``use_a1_paper=True`` so that the matrices would fit on the page. We also print grid minors $\\Delta_{c,k}$ (``print_red/blue_minors=True``) instead of their factorizations into cluster variables (``print_red/blue_factorizations=False``). To see the full list of options, type ``DoubleBraidClusterA.print_and_compile?``"}
︠85730d8f-4cf2-43cc-a215-7e38165af847s︠
DoubleBraidClusterA.print_single(wred=[2,1,-2,2,-2,-1,2,2],ured=[2,1],file_name="options_test",
		 comment="This is a comment. \\LaTeX\\ is allowed. If you zoom in enough, the minors/matrices actually become readable.",
		 print_curves=False,print_matrices=True,use_a1_paper=True,
		 print_red_grid_minors=True,print_blue_grid_minors=True,
		 print_red_factorizations=False, print_blue_factorizations=False)

︡659b30f0-bd59-4a11-b395-4eb81abba5eb︡{"html":"OK! <a href='tex/options_test.pdf'>options_test.pdf</a>"}︡{"done":true}
︠5b443a01-ff28-414d-923e-82752b49f8c3i︠
%md
One can also print mutliple quivers into the same file using the ``print_multiple`` function. To do so, specify a list of dictionaries of options. Each dictionary has to have ``ured`` and ``wred`` parameters. This is useful when tracing sequences of mutations and braid moves.
︡06e5a574-7c3a-4a3c-ad1d-df714d69ba77︡{"done":true,"md":"One can also print mutliple quivers into the same file using the ``print_multiple`` function. To do so, specify a list of dictionaries of options. Each dictionary has to have ``ured`` and ``wred`` parameters. This is useful when tracing sequences of mutations and braid moves."}
︠91a8bfac-1aca-4e92-af00-5a520081f41b︠
data=[
	{"wred":[2,1,-2,2,-2,-1,2,2],"ured":[2,1],"print_curves":False},
	{"wred":[2,1,-2,2,-2,2,-1,2],"ured":[2,1],"print_curves":False,"name":None,
	 "comment":"Swapping $-1$ and $2$ in positions 6 and 7 results in a mutation at vertex 7. This is the solid-special (B1) move."},
	]

DoubleBraidClusterA.print_multiple(data,file_name="multiple_test")
︡c84b254f-3bed-4e32-bb57-83ab8816ae21︡{"html":"OK! <a href='tex/multiple_test.pdf'>multiple_test.pdf</a>"}︡{"done":true}
︠62f78c0b-9146-4ae3-9724-a55f186d5df9i︠
%md
All the same stuff (except for matrices) works in arbitrary type. All you have to do is to specify an additional parameter ``typ`` consisting of a letter and a rank, e.g., ``typ=["D",4]``. Non simply laced types are ok.
︡4705d68b-a299-43cf-b3d2-f010d0e0921f︡{"done":true,"md":"All the same stuff (except for matrices) works in arbitrary type. All you have to do is to specify an additional parameter ``typ`` consisting of a letter and a rank, e.g., ``typ=[\"D\",4]``. Non simply laced types are ok."}
︠3891b5cc-241b-4c15-8459-da43465bf417s︠
DoubleBraidClusterGen.print_single(wred=[2,1,-2,2,-2,-1,2,2],ured=[2,1],typ=["G",2],file_name="G2_test")
︡19cfac32-8bcf-44cb-a587-8edc462ff2ab︡{"html":"OK! <a href='tex/G2_test.pdf'>G2_test.pdf</a>"}︡{"done":true}
︠e91ec15e-0867-47e2-8a9e-fc1d8b209745s︠
data=[
	{"wred":[2,1,-2,2,-2,-1,2,2],"ured":[2,1],"typ":["G",2],"name":"Folded $G_2$ quiver"},
	{"wred":[2,1,3,4,-2,2,-2,-1,-3,-4,2,2],"ured":[2,1,3,4],"typ":["D",4],"name":"Unfolded $D_4$ quiver"}
	]
DoubleBraidClusterGen.print_multiple(data,file_name="G2_vs_D4_test")
︡f89c46e7-8e68-4210-aa69-213ca2b6843f︡{"html":"OK! <a href='tex/G2_vs_D4_test.pdf'>G2_vs_D4_test.pdf</a>"}︡{"done":true}
︠3587341e-2441-423a-99f7-7ded0ebf1a13︠

︡38b8a824-69fb-4390-8394-8b8e15b00859︡
︠d643187c-fd3e-44bb-898c-9d03e771ef8c︠

︠7f6a3845-6c55-4825-a901-a1329437a30a︠

︠565d0655-0938-4652-942b-92d4b800f6e8︠

︠52735b15-5bd8-4ff4-8b5a-6847ec646506︠

︠ec9a554e-977b-46bb-8b10-1c5ce4d40475︠

︠b884c9e7-0073-4c26-85e6-bbe9df7eb7ff︠

︠871fb7d4-9014-4aa6-80bd-144d07acc169︠

︠fdc23522-8aba-43e1-8146-ee31c3ef9c91︠

︠06e4442e-de9f-4890-9e51-9e5cf7cb717c︠

︠b0e909aa-51f9-4275-8b3e-c6cd3322822f︠









